@@ -319,7 +319,7 @@ sub log
     $p{'message'} = uc($p{'level'}).' ['.ref($self).'] '.$p{'message'};
 
     if ($^O ne 'MSWin32') {
-        openlog('LISM', 'pid', 'local4');
+        openlog('LISM', 'pid', $self->{lism}->{_config}->{syslogfacility});
         setlogmask(Sys::Syslog::LOG_UPTO(Sys::Syslog::xlate($conf->{sysloglevel})));
         syslog($p{'level'}, $p{'message'});
         closelog();
@@ -451,11 +451,11 @@ sub _searchLism
         $attr = $lismopts->{attr};
     }
 
-    foreach my $filter (split(/, */, $filters)) {
+    foreach my $filter (split(/; */, $filters)) {
         $filter =~ s/^["']//;
         $filter =~ s/["']$//;
         if ($filter =~ /^\(?dn=/) {
-            ($base) = ($filter =~ /^\(?dn=(.*)\)?$/);
+            ($base) = ($filter =~ /^\(?dn=([^\)]*)\)?$/);
             $scope = 0;
             $filter = '(objectClass=*)';
         }
