@@ -193,7 +193,6 @@ sub _checkValues
     my $conf = $self->{_config};
     my $rc = LDAP_SUCCESS;
 
-    my $timestamp = strftime("%Y/%m/%d %H:%M:%S", localtime(time));
     foreach my $rule (@{$conf->{check}}) {
         my ($dn) = ($entryStr =~ /^dn: (.*)\n/);
         if (defined($rule->{dn}) && $dn !~ /$rule->{dn}/i) {
@@ -219,7 +218,7 @@ sub _checkValues
                     if (!defined($mrc)) {
                         return LDAP_OTHER;
                     } elsif (!$mrc) {
-                        $self->_perror("$timestamp: Maximum number of entries exceeded($dn): $error");
+                        $self->_perror("Maximum number of entries exceeded($dn): $error");
                         return LDAP_ADMIN_LIMIT_EXCEEDED;
                     }
                 }
@@ -261,7 +260,7 @@ sub _checkValues
                     if (!defined($mrc)) {
                         return LDAP_OTHER;
                     } elsif (!$mrc) {
-                        $self->_perror("$timestamp: Maximum number of entries exceeded($dn): $error");
+                        $self->_perror("Maximum number of entries exceeded($dn): $error");
                         return LDAP_SIZELIMIT_EXCEEDED;
                     }
                 }
@@ -269,28 +268,51 @@ sub _checkValues
             if ($type eq 'post') {
                 next;
             }
-            if (defined($cattr->{required}) && $cattr->{required}[0] eq 'on' && !@values) {
-                $self->_perror("$timestamp: $attr in $dn is required value");
+            if ($func eq 'add' && defined($cattr->{required}) && $cattr->{required}[0] eq 'on' && !@values) {
+                $self->_perror("$attr in $dn is required value");
                 $rc = LDAP_CONSTRAINT_VIOLATION;
             }
+            if (defined($cattr->{valexists}) && @values && $values[0] !~ /^ *$/) {
+                my $opts = $cattr->{lismopts};
+                my $filter = $opts->{filter};
+                if ($filter =~ /\(?dn=([^\)]+)/) {
+                    my $regexp = $1;
+                    my ($filterval) = ($dn =~ /($regexp)/i);
+                    $filter = "(dn=$filterval)";
+                }
+
+                my @vals = $self->_searchLism($opts, $filter);
+                if (defined($opts->{option}) && $opts->{option} =~ /addval=([^&]+)/) {
+                    push(@vals, split(/,/, $1));
+                }
+                foreach my $value (@values) {
+                    if (!grep(/^$value$/, @vals)) {
+                        $self->_perror("$attr=$value in $dn is invalid: value doesn't exist in entry");
+                        $rc = LDAP_CONSTRAINT_VIOLATION;
+                    }
+                }
+            }
             foreach my $value (@values) {
+                if ($value =~ /^ *$/) {
+                    next;
+                }
                 if (defined($cattr->{minlen}) && length($value) < $cattr->{minlen}[0]) {
-                    $self->_perror("$timestamp: $attr=$value in $dn is too short");
+                    $self->_perror("$attr=$value in $dn is too short");
                     $rc = LDAP_CONSTRAINT_VIOLATION;
                 }
                 if (defined($cattr->{maxlen}) && length($value) > $cattr->{maxlen}[0]) {
-                    $self->_perror("$timestamp: $attr=$value in $dn is too long");
+                    $self->_perror("$attr=$value in $dn is too long");
                     $rc = LDAP_CONSTRAINT_VIOLATION;
                 }
-                if (defined($cattr->{regexp}) && $value !~ /$cattr->{regexp}[0]/) {
-                    $self->_perror("$timestamp: $attr=$value in $dn is invalid: regular expression is $cattr->{regexp}[0]");
+                if (defined($cattr->{regexp}) && $value !~ /$cattr->{regexp}[0]/i) {
+                    $self->_perror("$attr=$value in $dn is invalid: regular expression is $cattr->{regexp}[0]");
                     $rc = LDAP_CONSTRAINT_VIOLATION;
                 }
                 if (defined($cattr->{function})) {
                     my $ecode = 0;
                     eval "\$ecode = $cattr->{function}[0](\$value)";
                     if (!$ecode) {
-                        $self->_perror("$timestamp: $attr=$value in $dn is invalid: function is $cattr->{function}[0]($ecode)");
+                        $self->_perror("$attr=$value in $dn is invalid: function is $cattr->{function}[0]($ecode)");
                         $rc = LDAP_CONSTRAINT_VIOLATION;
                     }
                 }
@@ -302,7 +324,7 @@ sub _checkValues
                     }
                     my @vals = $self->_searchLism($opts, $filter);
                     if (!@vals || !$vals[0]) {
-                        $self->_perror("$timestamp: $attr=$value in $dn is invalid: value doesn't exist in data");
+                        $self->_perror("$attr=$value in $dn is invalid: value doesn't exist in data");
                         $rc = LDAP_CONSTRAINT_VIOLATION;
                     }
                 }
@@ -316,7 +338,7 @@ sub _checkValues
                     $filter =~ s/\%i/$id/g;
                     my @vals = $self->_searchLism($opts, $filter);
                     if (@vals && $vals[0]) {
-                        $self->_perror("$timestamp: $attr=$value in $dn is invalid: value already exist in data");
+                        $self->_perror("$attr=$value in $dn is invalid: value already exist in data");
                         $rc = LDAP_CONSTRAINT_VIOLATION;
                     }
                 }
@@ -520,7 +542,8 @@ sub _perror
         }
     }
 
-    print $fd encode('utf8', "$message\n");
+    print $fd encode('utf8', strftime("%Y/%m/%d %H:%M:%S", localtime(time)).": $message\n");
+    $self->log(level => 'err', message => $message);
 
     if (!defined($conf->{file}) || $conf->{file}[0] ne 'stdout') {
         close($fd);
@@ -566,13 +589,13 @@ sub _checkConfig
             }
 
             foreach my $cattr (keys %{$rule->{attr}}) {
-                if (defined($rule->{attr}{$cattr}->{lismexist}) || defined($rule->{attr}{$cattr}->{lismunique})) {
+                if (defined($rule->{attr}{$cattr}->{lismexist}) || defined($rule->{attr}{$cattr}->{lismunique}) || defined($rule->{attr}{$cattr}->{valexists})) {
                     if (defined($rule->{attr}{$cattr}->{lismopts})) {
                         next;
                     }
                     my ($name) = keys %{$rule->{attr}{$cattr}};
                     my $lismopts = {};
-                    my ($base, $attr, $scope, $filter) = split(/\?/, $rule->{attr}{$cattr}->{$name}[0]);
+                    my ($base, $attr, $scope, $filter, $option) = split(/\?/, $rule->{attr}{$cattr}->{$name}[0]);
                     $lismopts->{base} = $base;
                     $lismopts->{attr} = $attr;
                     if ($scope) {
@@ -581,6 +604,9 @@ sub _checkConfig
                     if ($filter) {
                         $lismopts->{filter} = $filter;
                     }
+                    if ($option) {
+                        $lismopts->{option} = $option;
+                    }
                     $rule->{attr}{$cattr}->{lismopts} = $lismopts;
                 } elsif (defined($rule->{attr}{$cattr}->{maxentries})) {
                     my $maxentries = $rule->{attr}{$cattr}->{maxentries}[0];
