@@ -1598,18 +1598,33 @@ sub _writeUpdateLog
 sub random
 {
     my $self = shift;
-    my ($len) = @_;
+    my ($len, $attr, $info) = @_;
     my $string;
 
+    if ($attr) {
+        if (ref($info) eq 'ARRAY') {
+            my @list = @{$info};
+            for (my $i = 0; $i < @list; $i++) {
+                if ($list[$i] =~ /^$attr$/i && defined($list[$i + 1]) && $list[$i + 1]) {
+                    return $list[$i + 1];
+                }
+            }
+        } else {
+            my ($string) = ($info =~ /^$attr: *(.+)$/mi);
+            if ($string) {
+                return $string;
+            }
+        }
+    }
+
     my @chars;
     push(@chars, ('a'..'z'), ('A'..'Z',), (0..9));
 
     my ($sec, $microsec) = gettimeofday();
     srand($microsec);
 
-    $string = '';
-
     for (my $i = 0; $i < 10; $i++) {
+        $string = '';
         for (my $j = 0; $j < $len; $j++) {
             $string .= $chars[int(rand() * @chars)];
         }
