@@ -13,6 +13,7 @@ use Data::Dumper;
 
 our $controlAttr = 'lismControl';
 our $rawattrs = '^(jpegphoto|photo|objectSid|objectGUID|.*;binary)$';
+our $TIMEOUT = 5;
 
 =head1 NAME
 
@@ -657,8 +658,8 @@ sub _getConnect
         }
     }
 
-    $self->{ldap} = Net::LDAP->new($conf->{uri}[0]);
-    $self->{bind} = Net::LDAP->new($conf->{uri}[0]);
+    $self->{ldap} = Net::LDAP->new($conf->{uri}[0], timeout => $TIMEOUT);
+    $self->{bind} = Net::LDAP->new($conf->{uri}[0], timeout => $TIMEOUT);
 
     if (!defined($self->{ldap}) || !defined($self->{bind})) {
         $self->log(level => 'alert', message => "Can't connect $conf->{uri}[0]");
@@ -713,6 +714,7 @@ sub _checkConfig
     if (defined($conf->{deleteflag})) {
         foreach my $key (keys %{$conf->{deleteflag}}) {
             if ($conf->{deleteflag}{$key}->{filter}) {
+                $conf->{deleteflag}{$key}->{filter} =~ s/&amp;/&/g;
                 $conf->{deleteflag}{$key}->{filterobj} = Net::LDAP::Filter->new($conf->{deleteflag}{$key}->{filter});
             }
         }
@@ -853,14 +855,19 @@ sub _do_search
     $base =~ s/$self->{suffix}$/$conf->{nc}/i;
     $filterStr =~ s/$self->{suffix}(\)*)/$conf->{nc}$1/gi;
     $filterStr = encode('utf8', $filterStr);
+    if (!@attrs) {
+        @attrs = ('*');
+    } elsif (@attrs == 1 && $attrs[0] eq 'dn') {
+        push(@attrs, 'objectClass');
+    }
 
     my @rldapmap = reverse(@{$conf->{ldapmap}});
     my $msg;
     for (my $i = 1;;$i++) {
         if (keys %ctrl_class) {
-            $msg = $self->{ldap}->search(base => $base, scope => $scope, deref => $deref, sizelimit => $sizeLim, timelimit => $timeLim, filter => $filterStr, control => $control);
+            $msg = $self->{ldap}->search(base => $base, scope => $scope, deref => $deref, sizelimit => $sizeLim, timelimit => $timeLim, filter => $filterStr, attrs => \@attrs, control => $control);
         } else {
-            $msg = $self->{ldap}->search(base => $base, scope => $scope, deref => $deref, sizelimit => $sizeLim, timelimit => $timeLim, filter => $filterStr);
+            $msg = $self->{ldap}->search(base => $base, scope => $scope, deref => $deref, sizelimit => $sizeLim, timelimit => $timeLim, filter => $filterStr, attrs => \@attrs);
         }
 
         if ($msg->code) {
